@@ -22,24 +22,14 @@ from mootdx.utils import to_file
 @click.pass_context
 def cli(ctx, debug):
     ctx.obj['DEBUG'] = debug
-    click.echo(f"Debug mode is {'on' if debug else 'off'}")
-
-    if debug:
-        logging.basicConfig(level=logging.DEBUG)
+    ctx.obj['DEBUG'] and logging.basicConfig(level=logging.DEBUG)
 
 
 @cli.command(help='读取股票在线行情数据.')
 @click.option('-o', '--output', default=None, help='输出文件, 支持CSV, HDF5, Excel等格式.')
 @click.option('-s', '--symbol', default='600000', help='股票代码.')
-@click.option(
-    '-a',
-    '--action',
-    default='bars',
-    help='操作类型 (daily: 日线, minute: 一分钟线, fzline: 五分钟线).',
-)
-@click.option(
-    '-m', '--market', default='std', help='证券市场, 默认 std (std: 标准股票市场, ext: 扩展市场).'
-)
+@click.option('-a', '--action', default='bars', help='操作类型 (daily: 日线, minute: 一分钟线, fzline: 五分钟线).', )
+@click.option('-m', '--market', default='std', help='证券市场, 默认 std (std: 标准股票市场, ext: 扩展市场).')
 def quotes(symbol, action, market, output):
     client = Quotes.factory(market=market, multithread=True, heartbeat=True)
 
@@ -64,15 +54,8 @@ def quotes(symbol, action, market, output):
 @cli.command(help='读取股票本地行情数据.')
 @click.option('-d', '--tdxdir', default='C:/new_tdx', help='通达信数据目录.')
 @click.option('-s', '--symbol', default='600000', help='股票代码.')
-@click.option(
-    '-a',
-    '--action',
-    default='daily',
-    help='操作类型 (daily: 日线, minute: 一分钟线, fzline: 五分钟线).',
-)
-@click.option(
-    '-m', '--market', default='std', help='证券市场, 默认 std (std: 标准股票市场, ext: 扩展市场).'
-)
+@click.option('-a', '--action', default='daily', help='操作类型 (daily: 日线, minute: 一分钟线, fzline: 五分钟线).')
+@click.option('-m', '--market', default='std', help='证券市场, 默认 std (std: 标准股票市场, ext: 扩展市场).')
 @click.option('-o', '--output', default=None, help='输出文件, 支持 CSV, HDF5, Excel 等格式.')
 def reader(symbol, action, market, tdxdir, output):
     client = Reader.factory(market=market, tdxdir=tdxdir)
@@ -88,15 +71,8 @@ def reader(symbol, action, market, tdxdir, output):
 @cli.command(help='测试行情服务器.')
 @click.option('-l', '--limit', default=5, help='显示最快前几个，默认 5.')
 @click.option('-w', '--write', default=True, count=True, help='将最优服务器IP写入配置文件 ~/.mootdx/config.json.', )
-@click.option('-vv', '--verbose', default=False, count=True)
+@click.option('-v', '--verbose', default=False, count=True)
 def bestip(limit, write, verbose):
-    """
-    @todo 命令行最优线路配置功能调整
-    :param limit:
-    :param write:
-    :param verbose:
-    :return:
-    """
     verbose and logger.getLogger(level='DEBUG')
 
     config = get_config_path('config.json')
@@ -121,13 +97,14 @@ def bestip(limit, write, verbose):
 @click.option('-a', '--downall', count=True, help='下载全部文件')
 @click.option('-o', '--output', default=None, help='输出文件, 支持 CSV, HDF5, Excel, JSON 等格式.')
 @click.option('-d', '--downdir', default='output', help='下载文件目录')
-@click.option('-vv', '--verbose', count=True)
-def affair(parse, fetch, downdir, output, downall, verbose):
+@click.option('-l', '--listfile', count=True, default=False, help='显示全部文件')
+@click.option('-v', '--verbose', count=True)
+def affair(parse, fetch, downdir, output, downall, verbose, listfile):
     verbose and logger.getLogger(level='DEBUG')
 
     result = Affair.files()
 
-    if not fetch and not parse:
+    if listfile:
         t = PrettyTable(['filename', 'filesize', 'hash'])
         t.align['filename'] = 'l'
         t.align['filesize'] = 'l'
@@ -138,6 +115,7 @@ def affair(parse, fetch, downdir, output, downall, verbose):
             t.add_row([x['filename'], x['filesize'], x['hash']])
 
         print(t)
+        return
 
     if downall or fetch == 'all':
         feed = Affair.fetch(downdir=downdir)
