@@ -15,15 +15,14 @@ def download(downdir, filename):
 
 
 async def fetch_file(downdir, filename):
-    result = await asyncio.get_event_loop().run_in_executor(None, partial(financial.Financial().fetch_and_parse, report_hook=None, filename=filename, downdir=downdir))
+    result = await asyncio.get_event_loop().run_in_executor(None, partial(financial.Financial().fetch_only, report_hook=None, filename=filename, downdir=downdir))
     return result
 
 
 class Affair(object):
     @staticmethod
     def parse(downdir='.', filename=None):
-        """
-        按目录解析文件
+        """ 按目录解析文件
 
         :param downdir:
         :param filename:
@@ -45,24 +44,19 @@ class Affair(object):
 
     @staticmethod
     def files():
-        """
-        财务文件列表
+        """ 财务文件列表
 
-        :return:
+        :return: object
         """
 
-        history = financial.FinancialList()
-        results = history.fetch_and_parse()
-
-        return results
+        return financial.FinancialList().fetch_and_parse()
 
     @staticmethod
     def fetch(downdir='.', filename=None):
-        """
-        财务数据下载
+        """ 财务数据下载
 
-        :param downdir:
-        :param filename:
+        :param downdir: 下载路径
+        :param filename: 文件名
         :return:
         """
 
@@ -75,14 +69,12 @@ class Affair(object):
 
         if filename:
             log.info('下载文件 {}.'.format(filename))
-
-            with TqdmUpTo(unit='B', unit_scale=True, miniters=1, ascii=True) as t:
-                crawler.fetch_and_parse(report_hook=t.update_to, filename=filename, downdir=downdir)
-
+            crawler.fetch_only(report_hook=None, filename=filename, downdir=downdir)
             return True
 
         list_data = history.fetch_and_parse()
         tasks = []
+
         loop = asyncio.get_event_loop()
 
         for x in list_data:
